"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const node_sql_parser_1 = require("@joe-re/node-sql-parser");
const log4js = require("log4js");
const vscode_languageserver_1 = require("vscode-languageserver");
const logger = log4js.getLogger();
function createDiagnostics(uri, sql) {
    logger.debug(`createDiagnostics`);
    let diagnostics = [];
    try {
        const ast = node_sql_parser_1.Parser.parse(sql);
        logger.debug(`ast: ${JSON.stringify(ast)}`);
    }
    catch (e) {
        logger.debug('parse error');
        logger.debug(e);
        if (e.name !== 'SyntaxError') {
            throw e;
        }
        diagnostics.push({
            range: {
                start: { line: e.location.start.line - 1, character: e.location.start.column },
                end: { line: e.location.end.line - 1, character: e.location.end.column }
            },
            message: e.message,
            severity: vscode_languageserver_1.DiagnosticSeverity.Error,
            // code: number | string,
            source: 'sql',
            relatedInformation: []
        });
    }
    logger.debug(JSON.stringify(diagnostics));
    return { uri: uri, diagnostics };
}
exports.default = createDiagnostics;
//# sourceMappingURL=createDiagnostics.js.map