"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_languageserver_1 = require("vscode-languageserver");
const cache_1 = require("./cache");
const complete_1 = require("./complete");
const createDiagnostics_1 = require("./createDiagnostics");
const createConnection_1 = require("./createConnection");
const yargs_1 = require("yargs");
const SettingStore_1 = require("./SettingStore");
const getDatabaseClient_1 = require("./database_libs/getDatabaseClient");
const initializeLogging_1 = require("./initializeLogging");
const log4js = require("log4js");
function createServer() {
    let connection = createConnection_1.default(yargs_1.argv.method || 'node-ipc');
    initializeLogging_1.default();
    const logger = log4js.getLogger();
    let documents = new vscode_languageserver_1.TextDocuments();
    documents.listen(connection);
    let schema = [];
    connection.onInitialize((params) => {
        logger.debug(`onInitialize: ${params.rootPath}`);
        if (params.rootPath) {
            SettingStore_1.default.getInstance().setSettingFromFile(`${params.rootPath}/.sqllsrc.json`);
        }
        SettingStore_1.default.getInstance().on('change', () => __awaiter(this, void 0, void 0, function* () {
            try {
                const client = getDatabaseClient_1.default(SettingStore_1.default.getInstance().getSetting());
                schema = yield client.getSchema();
                logger.debug('get schema');
                logger.debug(JSON.stringify(schema));
            }
            catch (e) {
                logger.error(e);
            }
        }));
        return {
            capabilities: {
                textDocumentSync: documents.syncKind,
                completionProvider: {
                    resolveProvider: true,
                    triggerCharacters: ['.'],
                }
            }
        };
    });
    connection.onDidChangeTextDocument((params) => {
        logger.debug(`didChangeTextDocument: ${params.textDocument.uri}`);
        cache_1.default.set(params.textDocument.uri, params.contentChanges[0].text);
        const diagnostics = createDiagnostics_1.default(params.textDocument.uri, params.contentChanges[0].text);
        connection.sendDiagnostics(diagnostics);
    });
    connection.onCompletion((docParams) => {
        let text = cache_1.default.get(docParams.textDocument.uri);
        if (!text) {
            cache_1.default.setFromUri(docParams.textDocument.uri);
            text = cache_1.default.get(docParams.textDocument.uri);
        }
        logger.debug(text || '');
        const candidates = complete_1.default(text || '', {
            line: docParams.position.line,
            column: docParams.position.character
        }, schema).candidates;
        logger.debug(candidates.map(v => v.label).join(","));
        return candidates;
    });
    connection.onCompletionResolve((item) => {
        return item;
    });
    connection.listen();
    logger.info('start server');
    return connection;
}
exports.default = createServer;
//# sourceMappingURL=createServer.js.map