"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const log4js = require("log4js");
const logger = log4js.getLogger();
class AbstractClient {
    constructor(settings) {
        this.settings = settings;
    }
    getSchema() {
        return __awaiter(this, void 0, void 0, function* () {
            let schema = [];
            try {
                this.connect();
                const tables = yield this.getTables();
                schema = yield Promise.all(tables.map((v) => this.getColumns(v).then(columns => ({
                    database: this.settings.database,
                    tableName: v,
                    columns: columns.map(v => this.toColumnFromRawField(v))
                }))));
                this.disconnect();
            }
            catch (e) {
                this.disconnect();
                logger.error(e);
                throw e;
            }
            return schema;
        });
    }
    toColumnFromRawField(field) {
        return {
            columnName: field.field,
            description: `${field.field}(Type: ${field.type}, Null: ${field.null}, Default: ${field.default})`
        };
    }
}
exports.default = AbstractClient;
//# sourceMappingURL=AbstractClient.js.map