"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const mysql = require("mysql");
const AbstractClient_1 = require("./AbstractClient");
class MysqlClient extends AbstractClient_1.default {
    constructor(settings) {
        super(settings);
        this.connection = null;
    }
    connect() {
        this.connection = mysql.createConnection({
            host: this.settings.host || 'localhost',
            password: this.settings.password || '',
            user: this.settings.user || 'root',
            port: this.settings.port || 3306,
            database: this.settings.database || undefined
        });
    }
    disconnect() {
        if (this.connection) {
            this.connection.end();
        }
        this.connection = null;
    }
    getTables() {
        const sql = `
      SELECT table_name 
      FROM information_schema.tables
      WHERE table_schema = '${this.settings.database}'
    `;
        return new Promise((resolve, reject) => {
            if (!this.connection) {
                reject(new Error("Don't have database connection."));
                return;
            }
            this.connection.query(sql, (err, results) => {
                if (err) {
                    reject(new Error(err.message));
                    return;
                }
                const tables = results.map((v) => v[`table_name`]);
                resolve(tables);
            });
        });
    }
    getColumns(tableName) {
        const sql = `SHOW FULL FIELDS FROM ${tableName}`;
        return new Promise((resolve, reject) => {
            if (!this.connection) {
                reject(new Error("Don't have database connection."));
                return;
            }
            this.connection.query(sql, (err, results) => {
                if (err) {
                    reject(new Error(err.message));
                    return;
                }
                const columns = results.map((v) => ({
                    field: v.Field,
                    type: v.Type,
                    null: v.Null,
                    default: v.Default,
                    comment: v.Comment
                }));
                resolve(columns);
            });
        });
    }
}
exports.default = MysqlClient;
//# sourceMappingURL=MysqlClient.js.map